@@ -4,6 +4,7 @@ import itertools
 import logging
 import random
 import re
+import json
 import types
 from argparse import Namespace
 from collections import Counter, namedtuple
@@ -140,7 +141,7 @@ class BookmarkModelView(BaseModelView, ApplyFiltersMixin):
         if netloc and self.url_render_mode != 'netloc' and url_for_index_view_netloc:
             tag_links += [link(f'netloc:{netloc}', url_for_index_view_netloc, badge='success')]
         for tag in filter(None, model.tags.split(',')):
-            tag_links += [link(tag, get_index_view_url(flt0_tags_contain=tag.strip()), badge='default')]
+            tag_links += [link(tag, get_index_view_url(flt0_tags_contain=tag.strip()), badge='secondary')]
         res += [f'<div class="tag-list">{"".join(tag_links)}</div>']
         description = model.description and f'<div class="description">{escape(model.description)}</div>'
         if description:
@@ -151,7 +152,7 @@ class BookmarkModelView(BaseModelView, ApplyFiltersMixin):
     def get_detail_value(self, context, model, name):
         value = super().get_detail_value(context, model, name)
         if name == 'tags':
-            tags = (link(s.strip(), url_for('bookmark.index_view', flt0_tags_contain=s.strip()), badge='default')
+            tags = (link(s.strip(), url_for('bookmark.index_view', flt0_tags_contain=s.strip()), badge='secondary')
                     for s in (value or '').split(',') if s.strip())
             return Markup(f'<div class="tag-list">{"".join(tags)}</div>')
         if name == 'url':
@@ -194,13 +195,20 @@ class BookmarkModelView(BaseModelView, ApplyFiltersMixin):
         custom_model = types.SimpleNamespace(bukudb=bukudb, __name__='bookmark')
         super().__init__(custom_model, *args, **kwargs)
 
+    @property
+    def url_render_mode(self):
+        return app_param('URL_RENDER_MODE', DEFAULT_URL_RENDER_MODE)
+
     @property
     def page_size(self):
         return app_param('PER_PAGE', DEFAULT_PER_PAGE)
 
     @property
-    def url_render_mode(self):
-        return app_param('URL_RENDER_MODE', DEFAULT_URL_RENDER_MODE)
+    def page_size_options(self):
+        return tuple(sorted(set([self.page_size] + list(super().page_size_options))))
+
+    def get_safe_page_size(self, page_size):  # un-enforcing the restriction
+        return (page_size if self.can_set_page_size and page_size > 0 else self.page_size)
 
     def create_form(self, obj=None):
         form = super().create_form(obj)
@@ -209,7 +217,7 @@ class BookmarkModelView(BaseModelView, ApplyFiltersMixin):
             form.title.data = request.args.get('title', form.title.data)
             form.description.data = request.args.get('description', form.description.data)
             form.tags.data = request.args.get('tags', form.tags.data)
-            form.fetch.data = request.args.get('fetch', request.form.get('fetch', True))
+            form.fetch.data = request.args.get('fetch', request.form.get('fetch', app_param('AUTOFETCH', True)))
         return form
 
     def create_model(self, form):
@@ -269,6 +277,14 @@ class BookmarkModelView(BaseModelView, ApplyFiltersMixin):
             bookmarks = bukudb.get_rec_all(order=order)
         return self._apply_filters(bookmarks or [], filters)
 
+    @expose('/reorder', methods=['POST'])
+    def refresh(self):
+        filters = json.loads(request.form['filters'])
+        order = bs_filters.BookmarkOrderFilter.value(self._filters, filters)
+        self.bukudb.reorder(order)
+        flash(_('Reordered bookmarks in DB'), 'success')
+        return redirect(url_for('.index_view'))
+
     def get_list(self, page, sort_field, sort_desc, _, filters, page_size=None):
         bookmarks = self._from_filters(filters)
         count = len(bookmarks)
@@ -455,6 +471,13 @@ class TagModelView(BaseModelView, ApplyFiltersMixin):
     def page_size(self):
         return app_param('PER_PAGE', DEFAULT_PER_PAGE)
 
+    @property
+    def page_size_options(self):
+        return tuple(sorted(set([self.page_size] + list(super().page_size_options))))
+
+    def get_safe_page_size(self, page_size):  # un-enforcing the restriction
+        return (page_size if self.can_set_page_size and page_size > 0 else self.page_size)
+
     @expose('/refresh', methods=['POST'])
     def refresh(self):
         self._refresh()
@@ -516,8 +539,8 @@ class TagModelView(BaseModelView, ApplyFiltersMixin):
         def top_most_common_func(query, value, index):
             counter = Counter(x[index] for x in query)
             most_common = counter.most_common(value)
-            most_common_item = [x[0] for x in most_common]
-            return filter(lambda x: x[index] in most_common_item, query)
+            most_common_item = {x for x, count in most_common}
+            return filter((lambda x: x[index] in most_common_item), query)
 
         res += [
             bs_filters.TagBaseFilter(name, filter_type=FilterType.EQUAL),
@@ -630,7 +653,7 @@ def format_value(field, bookmark, spacing=''):
 
 def link(text, url, new_tab=False, html=False, badge=''):
     target = ('' if not new_tab else ' target="_blank"')
-    cls = ('' if not badge else f' class="btn label label-{badge}"')
+    cls = ('' if not badge else f' class="btn badge badge-{badge}"')
     return f'<a{cls} href="{escape(url)}"{target}>{text if html else escape(text)}</a>'
 
 
